using System;
using System.Collections.Generic;
using System.Text;
using Components.Calendar;
using Utils.Logs;

namespace WLog.Class
{
    class LogMeetingSet : RootMeetingSet
    {
        #region Variables
        private string vLogPath = "";
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public LogMeetingSet() : base() { }
        #endregion

        #region Methods
        /// <summary>
        /// Fill the LogSet with the log entries
        /// </summary>
        public override void Fill()
        {
            try
            {
                LogSet ls = new LogSet(this.vLogPath);
                ls.Fill();
                MeetingRow mr = new MeetingRow();
                foreach (LogRow lr in ls)
                {
                    mr.StartingDate = lr.Date;
                    mr.EndingDate = lr.Date.AddHours(0.5);
                    mr.Title = lr.Type + " - " + lr.Title + " - " + lr.Message;
                    mr.MeetingData = lr;
                    this.Add(mr);
                }
            }
            catch (Exception ex)
            {
                Log.Instance.Write(ex.Message, this, LogType.Error);
                throw;
            }
            base.Fill();
        }
        /// <summary>
        /// Fill the LogSet with the log entries
        /// </summary>
        /// <param name="_LogPath">The path of the log file</param>
        public void Fill(string _LogPath)
        {
            this.LogPath = _LogPath;
            this.Fill();
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the path of the log file
        /// </summary>
        public string LogPath { get { return this.vLogPath; } set { this.vLogPath = value; } }
        /// <summary>
        /// Gets the date of the first log
        /// </summary>
        public DateTime FirstLogDate
        {
            get
            {
                DateTime vFirstDate = new DateTime(9999, 12, 31);
                foreach (MeetingRow mr in this.MeetingList)
                {
                    if (mr.StartingDate < vFirstDate)
                        vFirstDate = mr.StartingDate;
                }
                return vFirstDate;
            }
        }
        #endregion
    }
}
